@@ -23,6 +23,8 @@ test_that("Scenario Encoding", {
                          conf = c(4L, 4L, 4L, 3L, 3L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 1L),
                          stringsAsFactors = FALSE)
   dat <- encode_scenarios(qualitative_scenarios, capabilities, mappings)
+  expect_equal(nrow(dat), 2)
+  expect_true(is.data.frame(dat))
 })
 test_that("Control Encoding", {
   capability_ids <- "1, 7"
@@ -35,5 +37,20 @@ test_that("Control Encoding", {
                          l = c(70, 0), ml = c(80, 20), h = c(95, 30),
                          conf = 3, stringsAsFactors = FALSE)
   dat <- derive_controls(capability_ids, capabilities, mappings)
+  expect_type(dat, "list")
+  expect_named(dat, c("1", "7"))
+  expect_equal(length(dat), 2)
+})
+
+test_that("Control ID Mappings", {
+  capability_ids <- "1, 7"
+  capabilities <- data.frame(capability_id = c(1L, 5L, 7L, 32L, 14L, 15L, 16L),
+                             domain_id = c("ORG", "ORG", "ORG", "ORG", "ORG", "ORG", "ORG"),
+                             capability = c("Capability 1.",  "Capability 5.", "Capability 7.", "Capability 32.", "Capability 14.", "Capability 15.", "Capability 16."),
+                             diff = c("5 - Optimized", "4 - Managed", "1 - Initial", "4 - Managed", "4 - Managed", "2 - Repeatable", "2 - Repeatable"),
+                             stringsAsFactors = FALSE)
+  dat <- derive_control_key(capability_ids, capabilities)
+  expect_type(dat, "list")
+  expect_named(dat, c("1", "7"))
   expect_equal(length(dat), 2)
 })
